Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(176)

Unified Diff: net/log/net_log_event_type_list.h

Issue 2448353002: [BlobAsync] Moving async handling into BlobStorageContext & quota out. (Closed)
Patch Set: comments Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/test/BUILD.gn ('k') | storage/browser/BUILD.gn » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/log/net_log_event_type_list.h
diff --git a/net/log/net_log_event_type_list.h b/net/log/net_log_event_type_list.h
index cda4669117ce1ce77f67743e800f7fa1786d4551..2508cc5051405a232291d802e1f74d227504652e 100644
--- a/net/log/net_log_event_type_list.h
+++ b/net/log/net_log_event_type_list.h
@@ -2072,12 +2072,13 @@ EVENT_TYPE(SERVICE_WORKER_ERROR_KILLED_WITH_BLOB)
EVENT_TYPE(SERVICE_WORKER_ERROR_KILLED_WITH_STREAM)
// This event is emitted when a request to be forwarded to a Service Worker has
// request body blobs, and it may be necessary to wait for them to finish
// construction. The END phase event parameter is:
// {
-// "success": Whether the request blobs finished construction successfully.
+// "success": Whether file sizes in the request body have been resolved
+// successfully
// }
-EVENT_TYPE(SERVICE_WORKER_WAITING_FOR_REQUEST_BODY_BLOB)
+EVENT_TYPE(SERVICE_WORKER_WAITING_FOR_REQUEST_BODY_FILES)
// This event is emitted when a request failed to be forwarded to a Service
// Worker, because it had a request body with a blob that failed to be
« no previous file with comments | « content/test/BUILD.gn ('k') | storage/browser/BUILD.gn » ('j') | no next file with comments »
@@ -2072,12 +2072,13 @@ EVENT_TYPE(SERVICE_WORKER_ERROR_KILLED_WITH_BLOB)
EVENT_TYPE(SERVICE_WORKER_ERROR_KILLED_WITH_STREAM)
// This event is emitted when a request to be forwarded to a Service Worker has
-// request body blobs, and it may be necessary to wait for them to finish
-// construction. The END phase event parameter is:
+// request body, and it may be necessary to wait for sizes of files in the body
+// to be resolved. The END phase event parameter is:
// {

Powered by Google App Engine
This is Rietveld 408576698